@@ -13,6 +13,7 @@
 
 # import json
 # import hashlib
+from datetime import datetime
 import logging as _logging
 from sre_compile import isstring
 # from typing import Union as _Union
@@ -251,6 +252,9 @@ def sanitize_quotes(value):
         value = [value]
 
     new_list = []
+    
+    if isinstance(value,datetime):
+        return value
     for item in value:
         if isinstance(item, (str)):
             item = item.replace("'", "&apos_")
