@@ -26,7 +26,8 @@ import colemen_utilities.file_utils as file
 import colemen_utilities.directory_utils as dirs
 import colemen_utilities.database_utils as db
 import colemen_utilities.console_utils as con
-# import colemen_utilities.drawio as drawio
+import colemen_utilities.validate_utils as valid
+import colemen_utilities.drawio as drawio
 
 
 
